==> cargo-binstall-1.16.5-1.src.tar.gz: cargo-binstall-1.16.5/crates/binstalk-fetchers/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.10.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.23...binstalk-fetchers-v0.10.24) - 2025-08-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.22...binstalk-fetchers-v0.10.23) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.10.32](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.31...binstalk-fetchers-v0.10.32) - 2025-12-20

### Other

- Replace doc_auto_cfg with doc_cfg ([#2402](https://github.com/cargo-bins/cargo-binstall/pull/2402))

## [0.10.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.30...binstalk-fetchers-v0.10.31) - 2025-12-05

### Other

- *(deps)* bump the deps group with 2 updates ([#2385](https://github.com/cargo-bins/cargo-binstall/pull/2385))

## [0.10.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.29...binstalk-fetchers-v0.10.30) - 2025-11-23

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.28...binstalk-fetchers-v0.10.29) - 2025-11-15

### Other

- *(deps)* bump bytes from 1.10.1 to 1.11.0 in the deps group ([#2371](https://github.com/cargo-bins/cargo-binstall/pull/2371))

## [0.10.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.27...binstalk-fetchers-v0.10.28) - 2025-11-09

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.26...binstalk-fetchers-v0.10.27) - 2025-10-25

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.25...binstalk-fetchers-v0.10.26) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))

## [0.10.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.24...binstalk-fetchers-v0.10.25) - 2025-09-14

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.21...binstalk-fetchers-v0.10.22) - 2025-06-21

### Added

- Add repository host Codeberg ([#2202](https://github.com/cargo-bins/cargo-binstall/pull/2202))

## [0.10.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.20...binstalk-fetchers-v0.10.21) - 2025-06-06

### Other

- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.19...binstalk-fetchers-v0.10.20) - 2025-05-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.18...binstalk-fetchers-v0.10.19) - 2025-05-16

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.17...binstalk-fetchers-v0.10.18) - 2025-04-05

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.16...binstalk-fetchers-v0.10.17) - 2025-03-19

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.10.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.15...binstalk-fetchers-v0.10.16) - 2025-03-15

### Other

- *(deps)* bump the deps group with 2 updates ([#2084](https://github.com/cargo-bins/cargo-binstall/pull/2084))
- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.10.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.14...binstalk-fetchers-v0.10.15) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.10.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.13...binstalk-fetchers-v0.10.14) - 2025-02-28

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.10.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.12...binstalk-fetchers-v0.10.13) - 2025-02-11

### Other

- *(deps)* bump the deps group with 2 updates (#2044)

## [0.10.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.11...binstalk-fetchers-v0.10.12) - 2025-02-04

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.10.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.10...binstalk-fetchers-v0.10.11) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.10.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.9...binstalk-fetchers-v0.10.10) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.10.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.8...binstalk-fetchers-v0.10.9) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.10.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.7...binstalk-fetchers-v0.10.8) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.10.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.6...binstalk-fetchers-v0.10.7) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.10.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.5...binstalk-fetchers-v0.10.6) - 2024-11-29

### Other

- Upgrade transitive dependencies ([#1985](https://github.com/cargo-bins/cargo-binstall/pull/1985))

## [0.10.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.4...binstalk-fetchers-v0.10.5) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.10.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.3...binstalk-fetchers-v0.10.4) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.10.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.2...binstalk-fetchers-v0.10.3) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.10.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.1...binstalk-fetchers-v0.10.2) - 2024-11-02

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.10.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.0...binstalk-fetchers-v0.10.1) - 2024-10-12

### Other

- updated the following local packages: binstalk-git-repo-api

## [0.10.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.9.1...binstalk-fetchers-v0.10.0) - 2024-09-11

### Other

- report to new stats server (with status) ([#1912](https://github.com/cargo-bins/cargo-binstall/pull/1912))
- Improve quickinstall telemetry failure message ([#1910](https://github.com/cargo-bins/cargo-binstall/pull/1910))

## [0.9.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.9.0...binstalk-fetchers-v0.9.1) - 2024-08-12

### Other
- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.9.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.8.0...binstalk-fetchers-v0.9.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader

==> cargo-binstall-1.16.6-1.src.tar.gz: cargo-binstall-1.16.6/crates/binstalk-fetchers/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.10.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.23...binstalk-fetchers-v0.10.24) - 2025-08-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.22...binstalk-fetchers-v0.10.23) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.10.33](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.32...binstalk-fetchers-v0.10.33) - 2025-12-27

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.32](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.31...binstalk-fetchers-v0.10.32) - 2025-12-20

### Other

- Replace doc_auto_cfg with doc_cfg ([#2402](https://github.com/cargo-bins/cargo-binstall/pull/2402))

## [0.10.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.30...binstalk-fetchers-v0.10.31) - 2025-12-05

### Other

- *(deps)* bump the deps group with 2 updates ([#2385](https://github.com/cargo-bins/cargo-binstall/pull/2385))

## [0.10.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.29...binstalk-fetchers-v0.10.30) - 2025-11-23

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.28...binstalk-fetchers-v0.10.29) - 2025-11-15

### Other

- *(deps)* bump bytes from 1.10.1 to 1.11.0 in the deps group ([#2371](https://github.com/cargo-bins/cargo-binstall/pull/2371))

## [0.10.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.27...binstalk-fetchers-v0.10.28) - 2025-11-09

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.26...binstalk-fetchers-v0.10.27) - 2025-10-25

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.25...binstalk-fetchers-v0.10.26) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))

## [0.10.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.24...binstalk-fetchers-v0.10.25) - 2025-09-14

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.21...binstalk-fetchers-v0.10.22) - 2025-06-21

### Added

- Add repository host Codeberg ([#2202](https://github.com/cargo-bins/cargo-binstall/pull/2202))

## [0.10.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.20...binstalk-fetchers-v0.10.21) - 2025-06-06

### Other

- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.19...binstalk-fetchers-v0.10.20) - 2025-05-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.18...binstalk-fetchers-v0.10.19) - 2025-05-16

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.17...binstalk-fetchers-v0.10.18) - 2025-04-05

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader, binstalk-git-repo-api

## [0.10.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.16...binstalk-fetchers-v0.10.17) - 2025-03-19

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.10.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.15...binstalk-fetchers-v0.10.16) - 2025-03-15

### Other

- *(deps)* bump the deps group with 2 updates ([#2084](https://github.com/cargo-bins/cargo-binstall/pull/2084))
- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.10.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.14...binstalk-fetchers-v0.10.15) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.10.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.13...binstalk-fetchers-v0.10.14) - 2025-02-28

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.10.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.12...binstalk-fetchers-v0.10.13) - 2025-02-11

### Other

- *(deps)* bump the deps group with 2 updates (#2044)

## [0.10.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.11...binstalk-fetchers-v0.10.12) - 2025-02-04

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.10.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.10...binstalk-fetchers-v0.10.11) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.10.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.9...binstalk-fetchers-v0.10.10) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.10.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.8...binstalk-fetchers-v0.10.9) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.10.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.7...binstalk-fetchers-v0.10.8) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.10.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.6...binstalk-fetchers-v0.10.7) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.10.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.5...binstalk-fetchers-v0.10.6) - 2024-11-29

### Other

- Upgrade transitive dependencies ([#1985](https://github.com/cargo-bins/cargo-binstall/pull/1985))

## [0.10.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.4...binstalk-fetchers-v0.10.5) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.10.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.3...binstalk-fetchers-v0.10.4) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.10.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.2...binstalk-fetchers-v0.10.3) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.10.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.1...binstalk-fetchers-v0.10.2) - 2024-11-02

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.10.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.10.0...binstalk-fetchers-v0.10.1) - 2024-10-12

### Other

- updated the following local packages: binstalk-git-repo-api

## [0.10.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.9.1...binstalk-fetchers-v0.10.0) - 2024-09-11

### Other

- report to new stats server (with status) ([#1912](https://github.com/cargo-bins/cargo-binstall/pull/1912))
- Improve quickinstall telemetry failure message ([#1910](https://github.com/cargo-bins/cargo-binstall/pull/1910))

## [0.9.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.9.0...binstalk-fetchers-v0.9.1) - 2024-08-12

### Other
- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.9.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-fetchers-v0.8.0...binstalk-fetchers-v0.9.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-types, binstalk-downloader, binstalk-downloader
